#======
# Copyright (c) IBM Corp. 2011, 2015.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


#
# IMPORTS
#
import os
import socket

from snack import *
from modules.network.dns import DNS

from viewer.__data__ import DNSSETUP_DNS_LIST_LABEL

#
# CONSTANTS
#


#
# CODE
#
class DNSConfig:
    """
    Represents the DNS configuration screen
    """

    def __init__(self, screen):
        """
        Constructor

        Args:
            screen (SnackScreen): SnackScreen instance
        """
        self.__screen = screen
        self.__dns = DNS()

        self.__hostnameLabel = Label("Hostname")
        self.__searchListLabel = Label("Search")
        dnsListLabel = Label(DNSSETUP_DNS_LIST_LABEL.localize())

        self.__hostname = Entry(15, socket.gethostname())
        self.__searchList = Entry(15, self.__dns.getSearchList())
        self.__dnsList = Entry(48, ' '.join(self.__dns.getNameservers()))

        self.__contentGrid = Grid(2, 3)
        self.__contentGrid.setField(self.__hostnameLabel, 0, 0, anchorLeft=1)
        self.__contentGrid.setField(dnsListLabel, 0, 1, anchorLeft=1)
        self.__contentGrid.setField(self.__searchListLabel, 0, 2, anchorLeft=1)

        self.__contentGrid.setField(self.__hostname, 1, 0, (1, 0, 0, 0))
        self.__contentGrid.setField(self.__dnsList, 1, 1, (1, 0, 0, 0))

        self.__contentGrid.setField(self.__searchList, 1, 2, (1, 0, 0, 0))

        self.__buttonsBar = ButtonBar(self.__screen,(("OK","ok"),("Back","back")))

        self.__grid = GridForm(self.__screen, "DNS Configuration", 1, 2)
        self.__grid.add(self.__contentGrid, 0, 0, (0,0,0,1))
        self.__grid.add(self.__buttonsBar, 0, 1)

    def __writeConfig(self):
        """
        Write configuration into the file
        """
        hostname = self.__hostname.value()
        os.popen("hostnamectl set-hostname %s" % hostname)

        nameservers = self.__dnsList.value().replace(',', ' ').strip().split()
        self.__dns.setNameservers(nameservers)
        self.__dns.setSearchList(self.__searchList.value())
        self.__dns.writeConfigFile()

    def run(self):
        """
        Draws the screen

        Returns:
            int: status of operation
        """
        result = self.__grid.run()
        self.__screen.popWindow()
        rc = self.__buttonsBar.buttonPressed(result)

        if rc == "back":
            return -1

        self.__writeConfig()
        return 0
